==> scanbot_sdk-2.10.0.tar.gz: lib/classical_components/document_live_detection.dart <==
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:logging/logging.dart';
import 'package:scanbot_sdk/classical_components/camera_configuration.dart';
import 'package:scanbot_sdk/document_scan_data.dart';
import 'package:scanbot_sdk/json/common_data.dart';
import 'package:scanbot_sdk/scanbot_sdk_models.dart';

import 'live_detection.dart';

class DocumentCameraLiveDetector extends LiveDetector {
  Function(DocumentContourScanningResult result) documentContourListener;
  Function(Page result) snapListener;
  Function(SdkLicenseException exception) errorListener;

  @override
  DetectorType detectorType = DetectorType.barcode;

  DocumentCameraLiveDetector(
      {required this.snapListener,
      required this.documentContourListener,
      required this.errorListener});

  Future<dynamic> _resultHandler(MethodCall methodCall) async {
    Map<String, dynamic> args = jsonDecode(methodCall.arguments);
    switch (methodCall.method) {
      case 'onContourDetected':
        if (!enabled) {
          return;
        }
        try {
          var scanningResult = DocumentContourScanningResult.fromJson(args);
          documentContourListener(scanningResult);
        } catch (e) {
          Logger.root.severe(e);
        }
        return;
      case 'onLicenseError':
        errorListener.call(SdkLicenseException.fromJson(args));
        return;
      default:
    }
  }

  Future<dynamic> setAutoSnappingEnabled(bool enabled) async {
    return await detectorChannel
        .invokeMethod("setAutoSnappingEnabled", {"enabled": enabled});
  }

  @override
  void registerResultHandler() {
    detectorChannel.setMethodCallHandler(_resultHandler);
  }

  Future<void> makeSnap() async {
    return await detectorChannel.invokeMethod("makeSnap");
  }
}

==> scanbot_sdk-2.13.0.tar.gz: lib/classical_components/document_live_detection.dart <==
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:logging/logging.dart';
import 'camera_configuration.dart';
import '../document_scan_data.dart';
import '../scanbot_sdk_models.dart';

import 'live_detection.dart';

class DocumentCameraLiveDetector extends LiveDetector {
  /// The callback that will be called each time some contour is detected. Or when the status of detection quality is changed
  Function(DocumentContourScanningResult result) documentContourListener;

  /// The callback that will be called each time the page snap is taken.
  Function(Page result) snapListener;

  /// The callback that will be called when there are problems with a license.
  Function(SdkLicenseException exception) errorListener;

  @override
  DetectorType detectorType = DetectorType.barcode;

  DocumentCameraLiveDetector(
      {required this.snapListener,
      required this.documentContourListener,
      required this.errorListener});

  Future<dynamic> _resultHandler(MethodCall methodCall) async {
    Map<String, dynamic> args = jsonDecode(methodCall.arguments);
    switch (methodCall.method) {
      case 'onContourDetected':
        if (!enabled) {
          return;
        }
        try {
          var scanningResult = DocumentContourScanningResult.fromJson(args);
          documentContourListener(scanningResult);
        } catch (e) {
          Logger.root.severe(e);
        }
        return;
      case 'onLicenseError':
        errorListener.call(SdkLicenseException.fromJson(args));
        return;
      default:
    }
  }

  Future<dynamic> setAutoSnappingEnabled(bool enabled) async {
    return await detectorChannel
        .invokeMethod("setAutoSnappingEnabled", {"enabled": enabled});
  }

  @override
  void registerResultHandler() {
    detectorChannel.setMethodCallHandler(_resultHandler);
  }

  Future<void> makeSnap() async {
    return await detectorChannel.invokeMethod("makeSnap");
  }
}
